@@ -45,10 +45,11 @@ to save data and another method to retrieve it. All the underlying complexities
 
  my $chronicle_w = Data::Chronicle::Writer->new( 
     cache_writer => $writer,
-    db_handle    => $dbh);
+    db_handle    => $dbh,
+    ttl          => 86400);
 
  my $chronicle_r = Data::Chronicle::Reader->new( 
-    cache_reader => $reader, 
+    cache_reader => $reader,
     db_handle    => $dbh);
 
 
@@ -73,7 +74,29 @@ has [qw(cache_writer db_handle)] => (
     default => undef,
 );
 
-=head3 C<< set("category1", "name1", $value1)  >>
+=head1 METHODS
+
+=head2 ttl
+
+If a TTL value is provided when constructing the instance, this will be used as the expiry time for the data.
+
+Expiry time is not currently recorded in the PostgreSQL database backend - it is only used for the cache layer.
+
+This represents the seconds until expiry, and default is C<undef>, meaning that keys will not expire.
+
+=cut
+
+has 'ttl' => (
+    isa      => 'Maybe[Int]',
+    is       => 'ro',
+    default  => undef,
+);
+
+=head2 set
+
+Example:
+
+    $chronicle_writer->set("category1", "name1", $value1);
 
 Store a piece of data "value1" under key "category1::name1" in Pg and Redis.
 
@@ -96,7 +119,7 @@ sub set {
     $value = JSON::to_json($value);
 
     my $key = $category . '::' . $name;
-    $self->cache_writer->set($key, $value);
+    $self->cache_writer->set($key => $value, $self->ttl ? ('EX' => $self->ttl) : ());
     $self->_archive($category, $name, $value, $rec_date) if $archive and $self->db_handle;
 
     return 1;
